==> openbazaar-0.0.2.tar.gz: openbazaar-0.0.2/lib/admin/classes/user_certify.php <==
<?php
/* *********************************************************
  饹̾: user_certify.php
  * 2001/5/29
  *   modi 2002-05-10 osCommers Ѥѹ
  *   modi 2002-05-21 osCommers IE5.01ưˤʤ뤿ѹ
  *                   PHP HTTP(Basic)ǧ  PHPå+ѥǧڤѹ
  * Naomi Suzukawa
  * suzukawa@bitscope.co.jp
  ----------------------------------------------------------
 ȤΥ桼ǧڤԤ
 ΤȤ˵Ͽ

  ѹ
  ********************************************************* */
class user_certify {
  // 桼
  var $apermissions = array("read"=>0, "write"=>0, "config"=>0, "users"=>0);
  var $npermission = 0;
  // åʥ顼
  var $semsg = "";
  // Υǡݻ֡
  var $login_log_span = 7;

  // ե饰
  var $isFirstTime = FALSE;
  // 󥨥顼ե饰
  var $isErr = FALSE;
  // Ѥߥե饰
  var $flg = FALSE;

  // 桼ID
  var $auth_user = '';
  // ॢȻ֡á
  //0php.iniե줿session.gc_maxlifetimeפ˽
  //  0礭ͤΤȤ:ꤵ줿֤ǥॢȤ
  //	var $maxlifetime = 0;

  /* -------------------------------------
	  ǽ : 󥹥ȥ饯
	   : $s_sid				- (i) åID
	 : TRUE/FALSE
	   : 桼ǧڤԤ
 ------------------------------------ */
  function user_certify($s_sid) {
    $this->user_admin_entry();						// ԡadminϿ

    // ॢȻ
    $actime = $this->time_out_time();

    $this->logoutCertifyLog($actime,$s_sid);		// ַвᤷΥơȤ˹

    $user = '';
    // ڡǥ桼ɣĤϤƤȤ
    if ($_POST['execute_login']) {
      $user = trim($_POST['loginuid']);
    }
    // åɣĤˤꡢ桼
    $oresult = tep_db_query("select * from login where sessionid='" . $s_sid . "'");
    if (!$oresult) {										// DB顼äȤ
      $this->putCertifyLog($s_sid,"e",$user);
      $this->isErr = TRUE;
      die('<br>'.TEXT_ERRINFO_DBERROR);
    }

    $nrow = tep_db_num_rows($oresult);						// 쥳ɷμ	  

    if ($nrow == 1) {										// ϿƤȤ
      $this->flg = TRUE;
      $arec = tep_db_fetch_array($oresult);				// 쥳ɤ
      if ($user && $user != trim($arec['account'])) {			// UIDڡϤƤȤơ֥ͤå
	$this->putCertifyLog($s_sid,"n",$user);
	$this->isErr = TRUE;
	return FALSE;
      }
      if ($arec['loginstatus'] != 'a') {					// Υ󤬥顼Ǥʤå
	//$this->isFirstTime = TRUE;
	//return FALSE;
      }
      if ($arec['logoutstatus'] != 'i') {					// 顼뤤ϡ˥ȡॢȤƤʤå
	//$this->isFirstTime = TRUE;
	//return FALSE;
      }

      if ($arec['lastaccesstime'] < $actime) {			// ॢȤƤ뤫å
	$this->putTimeOut($s_sid);
	$this->isFirstTime = TRUE;
	return FALSE;
      }
      $user = trim($arec['account']);
    }

    if (!$user) {		// ΤȤȴ
      $this->isFirstTime = TRUE;
      return FALSE;
    }
    // 桼ɣĥå
    $oresult = tep_db_query("select * from users where userid = '" . $user . "'");
    if (!$oresult) {										// DB顼äȤ
      $this->putCertifyLog($s_sid,"e",$user);
      $this->isErr = TRUE;
      die('<br>'.TEXT_ERRINFO_DBERROR);
    }

    $nrow = tep_db_num_rows($oresult);									// 쥳ɷμ
    if ($nrow == 1) {		
      $arec = tep_db_fetch_array($oresult);							// 쥳ɤ
      //			if ($oresult) tep_db_free_result($oresult);						// ơ֥륪֥Ȥ
      $pret = $this->password_check($s_sid,$arec['password'],$user);	// ѥɥå
      $aret = $this->user_parmission($s_sid,$user);					// 桼¤
      if ($pret && $aret) {
	$this->putCertifyLog($s_sid,"a",$user);
	$this->auth_user = $user;
	return TRUE;
      }
    }
    else {									// ϿƤʤ桼ΤȤ顼åå
      $this->putCertifyLog($s_sid,"n",$user);
    }
    //		if ($oresult) tep_db_free_result($oresult);					// ơ֥륪֥Ȥ

    $this->isErr = TRUE;
    return FALSE;
  }

  /* -------------------------------------
	  ǽ : ѥɥå
	   : $s_sid				- (i) åID
			 $pwd				- (i) ѥ
			 $auth_user			- (i) 桼ID
	 : TRUE/FALSE
 ------------------------------------ */
  function password_check($s_sid,$pwd,$auth_user) {
    if ($_POST['execute_login']) {
      if ($_POST['loginpwd']) {
	// Ϥ줿ѥɤ DES Ź沽ˡˤŹ沽
	//ʥơ֥ϿƤѥɤƱ֤Ѵ
	$sLogin_pwd = crypt($_POST['loginpwd'], $pwd);
	$n_max = 64;						// եĹ
	if (substr($pwd,0,$n_max) != substr($sLogin_pwd,0,$n_max)) {
	  $this->putCertifyLog($s_sid,"p",$auth_user);
	  return FALSE;
	}
      }
      else {
	$this->putCertifyLog($s_sid,"p",$auth_user);
	return FALSE;
      }
    }
    return TRUE;
  }

  /* -------------------------------------
	  ǽ : ॢȻ
	   : ʤ
	 : ॢȻ
 ------------------------------------ */
  function time_out_time() {

    //		$life_time = 0;
    //		if ($this->maxlifetime) {
    //			$life_time = $this->maxlifetime;
    //		}
    //		else {
    if ($GLOBALS['SESS_LIFE']) {
      $life_time = $GLOBALS['SESS_LIFE'];
    }
    else {
      $life_time = get_cfg_var('session.gc_maxlifetime');
    }
    //		}
    return date ("Y-m-d H:i:s", mktime (date(H), date(i), date(s) - $life_time ,date(m), date(d), date(Y)));
  }

  /* -------------------------------------
	  ǽ : 桼¼
	   : $s_sid				- (i) åID
			 $auth_user			- (i) 桼ID
	 : ǧڴλʸ󡢰۾ｪλ顼å
	   : 桼¤򥯥饹ѿ˥åȤ
 ------------------------------------ */
  function user_parmission($s_sid,$auth_user) {

    // 桼¼
    $oresult = tep_db_query("select permission from permissions where userid = '" . $auth_user . "'");
    if (!$oresult) {										// 顼äȤ
      $this->putCertifyLog($s_sid,"n",$auth_user);
      die('<br>'.TEXT_ERRINFO_DBERROR);
    }

    $nrow = tep_db_num_rows($oresult);		// 쥳ɷμ
    if ($nrow == 1) {						// Ϥ줿 UID Υ桼ϿƤȤ
      $arec = tep_db_fetch_array($oresult, DB_FETCHMODE_ASSOC);			// 쥳ɤ
      $this->npermission = $arec['permission'];		// ϿƤѥɤ
      $this->apermissions["read"] = ($this->npermission & 1);
      $this->apermissions["write"] = ($this->npermission & 2);
      $this->apermissions["config"] = ($this->npermission & 4);
      $this->apermissions["users"] = ($this->npermission & 8);
      return TRUE;
    }
    else {
      $this->putCertifyLog($s_sid,"n",$auth_user);
      return FALSE;
    }
    return FALSE;
  }
  /* -------------------------------------
	  ǽ : ԡadminϿ
	   : ʤ
	 : ʤ
	   : 桼ͤϿƤʤȤԡadminˤϿ
 ------------------------------------ */
  function user_admin_entry() {
    // ԡadminϿ
    $oresult = tep_db_query("select * from users");
    $nrow = tep_db_num_rows($oresult);		// 쥳ɷμ
    if ($nrow == 0) {						// 桼ͤϿƤʤȤϿ
      $s_pwd = crypt("admin");
      $result = tep_db_query("insert into users values ('admin','$s_pwd','ƥ','')");
      $result = tep_db_query("insert into permissions values ('admin',15)");
    }
  }

  /* -------------------------------------
	  ǽ : ǧڥϿ
	   : $s_sid				- (i) åID
			 $s_status			- (i) ơ
			 $auth_user			- (i) 桼ID
	 : ʤ
 ------------------------------------ */
  function putCertifyLog($s_sid,$s_status,$auth_user) {
    $auth_user = trim($auth_user);
    $this->deleteCertifyLog();			// ֤Ťǧڥ

    $time_ = date('Y-m-d H:i:s');

    if ($this->flg) {
      $result = tep_db_query("update login set lastaccesstime='$time_' where sessionid='$s_sid'");
      if (!$result) {
	$this->isErr = TRUE;
	die('<br>'.TEXT_ERRINFO_DBERROR);
      }
    }
    else {
      // The IP address of the remote host making the request.
      $as_ip = explode(".", getenv("REMOTE_ADDR"));
      // IPɥ쥹4Х˥ѥå
      $n_ip4 = 0;
      while (list($n_key, $s_byte) = each($as_ip)) {
	$n_ip4 = ($n_ip4 << 8) | (int)$s_byte;
      }

      $status_out_c = ''; $status_out = '';
      if ($s_status == 'a') {
	$status_out_c = ",logoutstatus";
	$status_out = ",'i'";
      }

      // Ͽ
      $result = tep_db_query("insert into login(sessionid,logintime,lastaccesstime,account,loginstatus,address$status_out_c) values('$s_sid','" . $time_ . "','" . $time_ . "','" . $auth_user . "','$s_status',$n_ip4$status_out)");
      if (!$result) {
	$this->isErr = TRUE;
	die('<br>'.TEXT_ERRINFO_DBERROR);
      }
    }
    return TRUE;
  }

  /* -------------------------------------
	  ǽ : ॢȤϿ
	   : $s_sid				- (i) åID
			 $auth_user			- (i) 桼ID
	 : ʤ
 ------------------------------------ */
  function putTimeOut($s_sid) {

    $time_ = date('Y-m-d H:i:s');

    if ($this->flg) {
      $result = tep_db_query("update login set logoutstatus='t', lastaccesstime='$time_' where sessionid='$s_sid'");
      if (!$result) {
	$this->isErr = TRUE;
	die('<br>'.TEXT_ERRINFO_DBERROR);
      }
    }
    return TRUE;
  }

  /* -------------------------------------
	  ǽ : ַвᤷΥơȤ˹
	   : $actime			- (i) ॢȻ
			 $s_sid				- (i) ơ
	 : ʤ
 ------------------------------------ */
  function logoutCertifyLog($actime,$s_sid) {
    // ߤΥåIDǤϤʤǽ郎ॢȻǡ󤷤Ƥ쥳ɤȤ
    $result = tep_db_query("update login set logoutstatus='o' where sessionid!='$s_sid' and lastaccesstime<'$actime' and logoutstatus='i'");
  }

  /* -------------------------------------
	  ǽ : ֤Ť
	   : ʤ
	 : ʤ
 ------------------------------------ */
  function deleteCertifyLog() {
    if ( 0 < $login_log_span) {
      $sspan_date = date ("Y-m-d H:i:s", mktime (date(H), date(i), date(s),date(m), date(d) - $login_log_span, date(Y)));
      $result = tep_db_query("delete from login where lastaccesstime < '$sspan_date'");
    }
  }
}

/* -------------------------------------
	  ǽ : 
	   : $erf				- (i) 顼֥饰
			 $s_status			- (i) ơ
	 : ʤ
 ------------------------------------ */
function logout_user($erf='',$s_status='') {
  if ($s_status) {	// ȤϿ
    $s_sid = session_id();
    $result = tep_db_query("update login set logoutstatus='$s_status' where sessionid='$s_sid'");
    $result = tep_db_query("delete from login where sessionid='$s_sid'");
  }

  // session_destroy();					// $PHPSESSID ϶ʸ
  $erf = ($erf ? "?erf=$erf" : "");
  header("Location: users_login.php$erf");
  exit;
}


/* =====================================
	ᥤ
 ===================================== */
if ($_GET['execute_logout_user']) { logout_user(FALSE,'o'); }

if (file_exists(DIR_WS_LANGUAGES . $_SESSION["language"] . '/user_certify.php')) {
  include(DIR_WS_LANGUAGES . $_SESSION["language"] . '/user_certify.php');
}
$ocertify = new user_certify(session_id());		// ǧ
if ($ocertify->isErr) { logout_user(1); }
elseif ($ocertify->isFirstTime) { logout_user(); }
?>

==> openbazaar-0.0.3.tar.gz: openbazaar-0.0.3/lib/admin/classes/user_certify.php <==
<?php
/* *********************************************************
  饹̾: user_certify.php
  * 2001/5/29
  *   modi 2002-05-10 osCommerce Ѥѹ
  *   modi 2002-05-21 osCommerce IE5.01ưˤʤ뤿ѹ
  *                   PHP HTTP(Basic)ǧ  PHPå+ѥǧڤѹ
  * Naomi Suzukawa
  * suzukawa@bitscope.co.jp
  ----------------------------------------------------------
 ȤΥ桼ǧڤԤ
 ΤȤ˵Ͽ

  ѹ
  ********************************************************* */
class user_certify {
  // 桼
  var $apermissions = array("read"=>0, "write"=>0, "config"=>0, "users"=>0);
  var $npermission = 0;
  // åʥ顼
  var $semsg = "";
  // Υǡݻ֡
  var $login_log_span = 7;

  // ե饰
  var $isFirstTime = FALSE;
  // 󥨥顼ե饰
  var $isErr = FALSE;
  // Ѥߥե饰
  var $flg = FALSE;

  // 桼ID
  var $auth_user = '';
  // ॢȻ֡á
  //0php.iniե줿session.gc_maxlifetimeפ˽
  //  0礭ͤΤȤ:ꤵ줿֤ǥॢȤ
  //	var $maxlifetime = 0;

  /* -------------------------------------
	  ǽ : 󥹥ȥ饯
	   : $s_sid				- (i) åID
	 : TRUE/FALSE
	   : 桼ǧڤԤ
 ------------------------------------ */
  function user_certify($s_sid) {
    $this->user_admin_entry();						// ԡadminϿ

    // ॢȻ
    $actime = $this->time_out_time();

    $this->logoutCertifyLog($actime,$s_sid);		// ַвᤷΥơȤ˹

    $user = '';
    // ڡǥ桼ɣĤϤƤȤ
    if ($_POST['execute_login']) {
      $user = trim($_POST['loginuid']);
    }
    // åɣĤˤꡢ桼
    $oresult = tep_db_query("select * from login where sessionid='" . $s_sid . "'");
    if (!$oresult) {										// DB顼äȤ
      $this->putCertifyLog($s_sid,"e",$user);
      $this->isErr = TRUE;
      die('<br>'.TEXT_ERRINFO_DBERROR);
    }

    $nrow = tep_db_num_rows($oresult);						// 쥳ɷμ	  

    if ($nrow == 1) {										// ϿƤȤ
      $this->flg = TRUE;
      $arec = tep_db_fetch_array($oresult);				// 쥳ɤ
      if ($user && $user != trim($arec['account'])) {			// UIDڡϤƤȤơ֥ͤå
	$this->putCertifyLog($s_sid,"n",$user);
	$this->isErr = TRUE;
	return FALSE;
      }
      if ($arec['loginstatus'] != 'a') {					// Υ󤬥顼Ǥʤå
	//$this->isFirstTime = TRUE;
	//return FALSE;
      }
      if ($arec['logoutstatus'] != 'i') {					// 顼뤤ϡ˥ȡॢȤƤʤå
	//$this->isFirstTime = TRUE;
	//return FALSE;
      }

      if ($arec['lastaccesstime'] < $actime) {			// ॢȤƤ뤫å
	$this->putTimeOut($s_sid);
	$this->isFirstTime = TRUE;
	return FALSE;
      }
      $user = trim($arec['account']);
    }

    if (!$user) {		// ΤȤȴ
      $this->isFirstTime = TRUE;
      return FALSE;
    }
    // 桼ɣĥå
    $oresult = tep_db_query("select * from users where userid = '" . $user . "'");
    if (!$oresult) {										// DB顼äȤ
      $this->putCertifyLog($s_sid,"e",$user);
      $this->isErr = TRUE;
      die('<br>'.TEXT_ERRINFO_DBERROR);
    }

    $nrow = tep_db_num_rows($oresult);									// 쥳ɷμ
    if ($nrow == 1) {		
      $arec = tep_db_fetch_array($oresult);							// 쥳ɤ
      //			if ($oresult) tep_db_free_result($oresult);						// ơ֥륪֥Ȥ
      $pret = $this->password_check($s_sid,$arec['password'],$user);	// ѥɥå
      $aret = $this->user_parmission($s_sid,$user);					// 桼¤
      if ($pret && $aret) {
	$this->putCertifyLog($s_sid,"a",$user);
	$this->auth_user = $user;
	return TRUE;
      }
    }
    else {									// ϿƤʤ桼ΤȤ顼åå
      $this->putCertifyLog($s_sid,"n",$user);
    }
    //		if ($oresult) tep_db_free_result($oresult);					// ơ֥륪֥Ȥ

    $this->isErr = TRUE;
    return FALSE;
  }

  /* -------------------------------------
	  ǽ : ѥɥå
	   : $s_sid				- (i) åID
			 $pwd				- (i) ѥ
			 $auth_user			- (i) 桼ID
	 : TRUE/FALSE
 ------------------------------------ */
  function password_check($s_sid,$pwd,$auth_user) {
    if ($_POST['execute_login']) {
      if ($_POST['loginpwd']) {
	// Ϥ줿ѥɤ DES Ź沽ˡˤŹ沽
	//ʥơ֥ϿƤѥɤƱ֤Ѵ
	$sLogin_pwd = crypt($_POST['loginpwd'], $pwd);
	$n_max = 64;						// եĹ
	if (substr($pwd,0,$n_max) != substr($sLogin_pwd,0,$n_max)) {
	  $this->putCertifyLog($s_sid,"p",$auth_user);
	  return FALSE;
	}
      }
      else {
	$this->putCertifyLog($s_sid,"p",$auth_user);
	return FALSE;
      }
    }
    return TRUE;
  }

  /* -------------------------------------
	  ǽ : ॢȻ
	   : ʤ
	 : ॢȻ
 ------------------------------------ */
  function time_out_time() {

    //		$life_time = 0;
    //		if ($this->maxlifetime) {
    //			$life_time = $this->maxlifetime;
    //		}
    //		else {
    if ($GLOBALS['SESS_LIFE']) {
      $life_time = $GLOBALS['SESS_LIFE'];
    }
    else {
      $life_time = get_cfg_var('session.gc_maxlifetime');
    }
    //		}
    return date ("Y-m-d H:i:s", mktime (date(H), date(i), date(s) - $life_time ,date(m), date(d), date(Y)));
  }

  /* -------------------------------------
	  ǽ : 桼¼
	   : $s_sid				- (i) åID
			 $auth_user			- (i) 桼ID
	 : ǧڴλʸ󡢰۾ｪλ顼å
	   : 桼¤򥯥饹ѿ˥åȤ
 ------------------------------------ */
  function user_parmission($s_sid,$auth_user) {

    // 桼¼
    $oresult = tep_db_query("select permission from permissions where userid = '" . $auth_user . "'");
    if (!$oresult) {										// 顼äȤ
      $this->putCertifyLog($s_sid,"n",$auth_user);
      die('<br>'.TEXT_ERRINFO_DBERROR);
    }

    $nrow = tep_db_num_rows($oresult);		// 쥳ɷμ
    if ($nrow == 1) {						// Ϥ줿 UID Υ桼ϿƤȤ
      $arec = tep_db_fetch_array($oresult, DB_FETCHMODE_ASSOC);			// 쥳ɤ
      $this->npermission = $arec['permission'];		// ϿƤѥɤ
      $this->apermissions["read"] = ($this->npermission & 1);
      $this->apermissions["write"] = ($this->npermission & 2);
      $this->apermissions["config"] = ($this->npermission & 4);
      $this->apermissions["users"] = ($this->npermission & 8);
      return TRUE;
    }
    else {
      $this->putCertifyLog($s_sid,"n",$auth_user);
      return FALSE;
    }
    return FALSE;
  }
  /* -------------------------------------
	  ǽ : ԡadminϿ
	   : ʤ
	 : ʤ
	   : 桼ͤϿƤʤȤԡadminˤϿ
 ------------------------------------ */
  function user_admin_entry() {
    // ԡadminϿ
    $oresult = tep_db_query("select * from users");
    $nrow = tep_db_num_rows($oresult);		// 쥳ɷμ
    if ($nrow == 0) {						// 桼ͤϿƤʤȤϿ
      $s_pwd = crypt("admin");
      $result = tep_db_query("insert into users values ('admin','$s_pwd','ƥ','')");
      $result = tep_db_query("insert into permissions values ('admin',15)");
    }
  }

  /* -------------------------------------
	  ǽ : ǧڥϿ
	   : $s_sid				- (i) åID
			 $s_status			- (i) ơ
			 $auth_user			- (i) 桼ID
	 : ʤ
 ------------------------------------ */
  function putCertifyLog($s_sid,$s_status,$auth_user) {
    $auth_user = trim($auth_user);
    $this->deleteCertifyLog();			// ֤Ťǧڥ

    $time_ = date('Y-m-d H:i:s');

    if ($this->flg) {
      $result = tep_db_query("update login set lastaccesstime='$time_' where sessionid='$s_sid'");
      if (!$result) {
	$this->isErr = TRUE;
	die('<br>'.TEXT_ERRINFO_DBERROR);
      }
    }
    else {
      // The IP address of the remote host making the request.
      $as_ip = explode(".", getenv("REMOTE_ADDR"));
      // IPɥ쥹4Х˥ѥå
      $n_ip4 = 0;
      while (list($n_key, $s_byte) = each($as_ip)) {
	$n_ip4 = ($n_ip4 << 8) | (int)$s_byte;
      }

      $status_out_c = ''; $status_out = '';
      if ($s_status == 'a') {
	$status_out_c = ",logoutstatus";
	$status_out = ",'i'";
      }

      // Ͽ
      $result = tep_db_query("insert into login(sessionid,logintime,lastaccesstime,account,loginstatus,address$status_out_c) values('$s_sid','" . $time_ . "','" . $time_ . "','" . $auth_user . "','$s_status',$n_ip4$status_out)");
      if (!$result) {
	$this->isErr = TRUE;
	die('<br>'.TEXT_ERRINFO_DBERROR);
      }
    }
    return TRUE;
  }

  /* -------------------------------------
	  ǽ : ॢȤϿ
	   : $s_sid				- (i) åID
			 $auth_user			- (i) 桼ID
	 : ʤ
 ------------------------------------ */
  function putTimeOut($s_sid) {

    $time_ = date('Y-m-d H:i:s');

    if ($this->flg) {
      $result = tep_db_query("update login set logoutstatus='t', lastaccesstime='$time_' where sessionid='$s_sid'");
      if (!$result) {
	$this->isErr = TRUE;
	die('<br>'.TEXT_ERRINFO_DBERROR);
      }
    }
    return TRUE;
  }

  /* -------------------------------------
	  ǽ : ַвᤷΥơȤ˹
	   : $actime			- (i) ॢȻ
			 $s_sid				- (i) ơ
	 : ʤ
 ------------------------------------ */
  function logoutCertifyLog($actime,$s_sid) {
    // ߤΥåIDǤϤʤǽ郎ॢȻǡ󤷤Ƥ쥳ɤȤ
    $result = tep_db_query("update login set logoutstatus='o' where sessionid!='$s_sid' and lastaccesstime<'$actime' and logoutstatus='i'");
  }

  /* -------------------------------------
	  ǽ : ֤Ť
	   : ʤ
	 : ʤ
 ------------------------------------ */
  function deleteCertifyLog() {
    if ( 0 < $login_log_span) {
      $sspan_date = date ("Y-m-d H:i:s", mktime (date(H), date(i), date(s),date(m), date(d) - $login_log_span, date(Y)));
      $result = tep_db_query("delete from login where lastaccesstime < '$sspan_date'");
    }
  }
}

/* -------------------------------------
	  ǽ : 
	   : $erf				- (i) 顼֥饰
			 $s_status			- (i) ơ
	 : ʤ
 ------------------------------------ */
function logout_user($erf='',$s_status='') {
  if ($s_status) {	// ȤϿ
    $s_sid = session_id();
    $result = tep_db_query("update login set logoutstatus='$s_status' where sessionid='$s_sid'");
    $result = tep_db_query("delete from login where sessionid='$s_sid'");
  }

  // session_destroy();					// $PHPSESSID ϶ʸ
  $erf = ($erf ? "?erf=$erf" : "");
  header("Location: users_login.php$erf");
  exit;
}


/* =====================================
	ᥤ
 ===================================== */
if ($_GET['execute_logout_user']) { logout_user(FALSE,'o'); }

if (file_exists(DIR_WS_LANGUAGES . $_SESSION["language"] . '/user_certify.php')) {
  include(DIR_WS_LANGUAGES . $_SESSION["language"] . '/user_certify.php');
}
$ocertify = new user_certify(session_id());		// ǧ
if ($ocertify->isErr) { logout_user(1); }
elseif ($ocertify->isFirstTime) { logout_user(); }
?>
